/***************************************************************************
*   KBlocks, a falling blocks game for KDE                                *
*   Copyright (C) 2010 Zhongjie Cai <squall.leonhart.cai@gmail.com>       *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
***************************************************************************/
#include "KBlocksDefine.h"

const char *KBlocksRecordText[RecordDataType_Max_Count] = {
    "GameCount",
    "GameSeed",
    "Skipped",
    "MovePieceLeft",
    "MovePieceRight",
    "MovePieceUp",
    "MovePieceDown",
    "RotatePieceCW",
    "RotatePieceCCW",
    "GameOneStep",
    "PunishLineCount",
    "PunishLineSeed",
};
